@@ -1,10 +1,9 @@
 """ Model for output of GSP data """
 import logging
-from xarray.ufuncs import isnan, isinf
 
-from nowcasting_dataset.data_sources.datasource_output import (
-    DataSourceOutput,
-)
+from xarray.ufuncs import isinf, isnan
+
+from nowcasting_dataset.data_sources.datasource_output import DataSourceOutput
 from nowcasting_dataset.time import make_random_time_vectors
 
 logger = logging.getLogger(__name__)
