@@ -6,10 +6,12 @@ import numpy as np
 import pandas as pd
 import pytest
 
+import nowcasting_dataset
+from nowcasting_dataset.config.load import load_yaml_configuration
 from nowcasting_dataset.dataset import datamodule
+from nowcasting_dataset.dataset.batch import Batch
 from nowcasting_dataset.dataset.datamodule import NowcastingDataModule
 from nowcasting_dataset.dataset.split.split import SplitMethod
-from nowcasting_dataset.dataset.batch import Batch
 import nowcasting_dataset.utils as nd_utils
 
 logging.basicConfig(format="%(asctime)s %(levelname)s %(pathname)s %(lineno)d %(message)s")
